# Generated by roxygen2: do not edit by hand

S3method(predict,OHPL)
export(FOP)
export(OHPL)
export(OHPL.RMSEP)
export(OHPL.sim)
export(cv.OHPL)
export(dlc)
export(proto)
import(pls)
importFrom(glmnet,cv.glmnet)
importFrom(mvtnorm,rmvnorm)
importFrom(stats,coef)
importFrom(stats,median)
importFrom(stats,predict)
importFrom(stats,rnorm)
importFrom(stats,sd)
